@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: torrent.c 9051 2009-09-07 06:19:26Z charles $
+ * $Id: torrent.c 9378 2009-10-22 04:40:13Z charles $
  */
 
 #include <sys/types.h> /* stat */
@@ -1821,7 +1821,12 @@ tr_torrentSetPeerLimit( tr_torrent * tor,
 {
     assert( tr_isTorrent( tor ) );
 
-    tor->maxConnectedPeers = maxConnectedPeers;
+    if ( tor->maxConnectedPeers != maxConnectedPeers )
+    {
+        tor->maxConnectedPeers = maxConnectedPeers;
+
+        tr_torrentSetDirty( tor );
+    }
 }
 
 uint16_t
@@ -2306,7 +2311,8 @@ struct LocationData
 static void
 setLocation( void * vdata )
 {
-    int err = 0;
+    tr_bool err = FALSE;
+    tr_bool verify_needed = FALSE;
     struct LocationData * data = vdata;
     tr_torrent * tor = data->tor;
     const tr_bool do_move = data->move_from_old_location;
@@ -2344,10 +2350,15 @@ setLocation( void * vdata )
             {
                 errno = 0;
                 tr_torinf( tor, "moving \"%s\" to \"%s\"", oldpath, newpath );
-                if( tr_moveFile( oldpath, newpath ) ) {
-                    err = 1;
-                    tr_torerr( tor, "error moving \"%s\" to \"%s\": %s",
-                                    oldpath, newpath, tr_strerror( errno ) );
+                if( rename( oldpath, newpath ) )
+                {
+                    verify_needed = TRUE;
+                    if( tr_moveFile( oldpath, newpath ) )
+                    {
+                        err = TRUE;
+                        tr_torerr( tor, "error moving \"%s\" to \"%s\": %s",
+                                        oldpath, newpath, tr_strerror( errno ) );
+                    }
                 }
             }
             else if( !stat( newpath, &sb ) )
@@ -2368,11 +2379,13 @@ setLocation( void * vdata )
         if( !err )
         {
             /* blow away the leftover subdirectories in the old location */
-            tr_torrentDeleteLocalData( tor, remove );
+            if( do_move && verify_needed )
+                tr_torrentDeleteLocalData( tor, remove );
 
             /* set the new location and reverify */
             tr_torrentSetDownloadDir( tor, location );
-            tr_torrentVerify( tor );
+            if( verify_needed )
+                tr_torrentVerify( tor );
         }
     }
 
